from . import version
from .api import watch

__title__ = 'pylibsass'
__version__ = version.__version__
__author__ = 'Ryan Senkbeil'
__license__ = 'MIT'
__copyright__ = 'Copyright 2013 Ryan Senkbeil'
